# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .get_data_source import *
from .provider import *
from .resource import *
_utilities.register(
    resource_modules="""
[
 {
  "pkg": "null",
  "mod": "index/resource",
  "fqn": "pulumi_null",
  "classes": {
   "null:index/resource:Resource": "Resource"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "null",
  "token": "pulumi:providers:null",
  "fqn": "pulumi_null",
  "class": "Provider"
 }
]
"""
)
